@@ -1,4 +1,5 @@
 from django.db import models
+from django.utils.encoding import smart_unicode
 
 from adrest import settings
 from adrest.signals import api_request_finished
@@ -52,9 +53,13 @@ if settings.ACCESS_LOG:
             return
 
         try:
-            content = response.content.decode('utf-8')[:5000]
+            content = smart_unicode(response.content)[:5000]
         except (UnicodeDecodeError, UnicodeEncodeError):
-            content = response.content[:5000]
+            if response and response['Content-Type'].lower() not in \
+                   [emitter.media_type.lower() for emitter in resource.emitters]:
+                content = 'Invalid response content encoding'
+            else:
+                content = response.content[:5000]
 
         Access.objects.create(
             uri=request.path_info,
@@ -63,8 +68,7 @@ if settings.ACCESS_LOG:
             status_code=response.status_code,
             request='%s\n\n%s' % (str(request.META), str(getattr(request, 'data', ''))),
             identifier=resource.identifier or request.META.get('REMOTE_ADDR', 'anonymous'),
-            response=content,
-        )
+            response=content)
 
     api_request_finished.connect(save_log)
 
